@@ -10,11 +10,11 @@ def addresses(oscn_html):
     soup = BeautifulSoup(oscn_html, "html.parser")
 
     table = soup.find("table", "partytable addresses")
-    header = table.thead.find_all('th')
+    header = table.thead.find_all("th")
     keys = list(map(get_text, header))
 
-    for row in table.tbody.find_all('tr'):
-        data = row.find_all('td')
+    for row in table.tbody.find_all("tr"):
+        data = row.find_all("td")
         values = map(get_text, data)
         new_dict = {k: v for k, v in zip(keys, values)}
         address_list.append(new_dict)
